<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	
<xsl:param name="component">all</xsl:param>
<xsl:param name="oDescFile"></xsl:param>
<xsl:param name="mDescFile"></xsl:param>
<xsl:param name="upgradeFile"></xsl:param>
<xsl:param name="category"></xsl:param>

<xsl:template match="/">
  <xsl:apply-templates select="CLI"/>
</xsl:template>

<xsl:template match="CLI">
  <xsl:choose>
  <xsl:when test="$component='all'">
    <xsl:if test="$category='all'">
      <xsl:apply-templates select="NOUN">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="not($category='all')">
      <xsl:apply-templates select="NOUN[@category=$category]">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:when>
  <xsl:when test="$component='delta'">
    <xsl:if test="$category='all'">
      <xsl:apply-templates select="NOUN[@status!='']">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="not($category='all')">
      <xsl:apply-templates select="NOUN[@status!='' and @category=$category]">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="NOUN[@name=$component]"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="NOUN">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="fullname" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/FULL_NAME|
       $odoc/CLI/NOUN[@name=current()/@name]/FULL_NAME"/>
  <font size="3">
  <H3>Command Name = <xsl:value-of select="@name"/>
    <xsl:if test="$fullname!=''">
      (<xsl:value-of select="$fullname"/>)
    </xsl:if>
    <xsl:if test="@status!=''">
      <font color="red"> (<xsl:value-of select="@status"/>)</font>
    </xsl:if>
  </H3>
  </font>
  <xsl:if test="@tablename!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <font size="3">
      <H4>Table Name = <xsl:value-of select="@tablename"/></H4>
      </font>
    </div>
  </xsl:if>
  <xsl:call-template name="cmd-description"/>
  <xsl:call-template name="cmd-token-list"/>
  <xsl:call-template name="containment"/>
  <xsl:call-template name="primary-key"/>
  <xsl:call-template name="foreign-key"/>
  <xsl:call-template name="unique-key"/>
  <xsl:call-template name="check-rule"/>
  <xsl:call-template name="command-type"/>
  <xsl:call-template name="example"/>
  <xsl:call-template name="tables-display"/>
  <xsl:call-template name="table-display"/>
  <xsl:call-template name="upgrade-impact"/>
  <xsl:call-template name="table-change-history"/>
  <xsl:apply-templates select="COMMAND_PARAMETER"/>
</xsl:template>

<xsl:template name="cmd-description">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="desc" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/DESCRIPTION|
       $odoc/CLI/NOUN[@name=current()/@name]/DESCRIPTION"/>
  <xsl:variable name="caution" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/DESCRIPTION/CAUTION|
       $odoc/CLI/NOUN[@name=current()/@name]/DESCRIPTION/CAUTION"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="$desc/text()"/>
      </xsl:call-template>
      <xsl:if test="$caution!=''">
        <img src="caution.jpg" width="35" height="30" alt="" border="0" align=""/>
        <b><font color="red"><xsl:value-of select="$caution"/></font></b>
      </xsl:if>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="cmd-token-list">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <b><xsl:value-of select="@name"/></b>
    <xsl:for-each select="COMMAND_PARAMETER/TOKEN_NAME">
      <xsl:sort select="@varname"/>
      <xsl:text> </xsl:text>
      <font color="blue"><b>[</b></font>
      <xsl:if test="not(@status!='')">
        <xsl:value-of select="@varname"/>
      </xsl:if>
      <xsl:if test="@status!=''">
        <font color="red"><xsl:value-of select="@varname"/></font>
      </xsl:if>
      <font color="blue"><b>]</b></font>
    </xsl:for-each>
  </div>
</xsl:template>

<xsl:template name="example">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="sexample" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/EXAMPLE"/>
  <xsl:variable name="example" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/EXAMPLE"/>
  <xsl:if test="$sexample!=''">
    <dl><dl>
      <li><b>Examples:</b></li>
      <ol type="1"><xsl:apply-templates select="$sexample/STATEMENT"/></ol>
      <xsl:apply-templates select="$sexample/EXAMPLE_NOTE"/>
      <xsl:if test="$sexample/CAUTION!=''">
        <xsl:call-template name="display-caution">
          <xsl:with-param name="text" select="$sexample/CAUTION"/>
        </xsl:call-template>
      </xsl:if>
    </dl></dl>
  </xsl:if>
  <xsl:if test="not($sexample!='') and $example!=''">
    <dl><dl>
      <li><b>Examples:</b></li>
      <ol type="1"><xsl:apply-templates select="$example/STATEMENT"/></ol>
      <xsl:apply-templates select="$example/EXAMPLE_NOTE"/>
      <xsl:if test="$example/CAUTION!=''">
        <xsl:call-template name="display-caution">
          <xsl:with-param name="text" select="$example/CAUTION"/>
        </xsl:call-template>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="RULE|STATEMENT">
  <xsl:if test="not(@status!='') or @status!='removed'">
    <li>
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="current()"/>
      </xsl:call-template>
    </li>
  </xsl:if>
</xsl:template>

<xsl:template match="EXAMPLE_NOTE|NOTE">
  <br/><dl><b>Note: </b><xsl:value-of select="current()"/></dl>
</xsl:template>

<xsl:template name="containment">
  <xsl:if test="CONTAINMENT!=''">
    <dl><dl>
      <li><b>Containment Area:</b></li>
      <xsl:apply-templates select="CONTAINMENT"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CONTAINMENT">
  <xsl:call-template name="display-cmd-attr">
    <xsl:with-param name="function" select="'display-containment'"/>
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="display-containment">
  <xsl:for-each select="AREA">
    <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    <xsl:value-of select="current()"/>
  </xsl:for-each>
</xsl:template>

<xsl:template name="primary-key">
  <xsl:if test="PRIMARY_KEY!=''">
    <dl><dl>
      <li><b>Primary Key:</b></li>
      <xsl:apply-templates select="PRIMARY_KEY"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="PRIMARY_KEY">
  <xsl:call-template name="display-cmd-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="foreign-key">
  <xsl:if test="FOREIGN_KEY!=''">
    <dl><dl>
      <li><b>Foreign Key:</b></li>
      <xsl:if test="not(FOREIGN_KEY/@status='changed')">
        <xsl:for-each select="FOREIGN_KEY/CONSTRAINT">
          <xsl:call-template name="display-cmd-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="FOREIGN_KEY/@status='changed'">
        <xsl:apply-templates select="FOREIGN_KEY/CONSTRAINT">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CONSTRAINT">
  <xsl:call-template name="display-cmd-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="unique-key">
  <xsl:if test="UNIQUE_KEY!='' or UNIQUE_INDEX!=''">
    <dl><dl>
      <li><b>Unique Key:</b></li>
      <xsl:if test="not(UNIQUE_KEY/@status='changed')">
        <xsl:for-each select="UNIQUE_KEY/CONSTRAINT">
          <xsl:call-template name="display-cmd-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="not(UNIQUE_INDEX/@status='changed')">
        <xsl:for-each select="UNIQUE_INDEX/INDEX">
          <xsl:call-template name="display-cmd-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="UNIQUE_KEY/@status='changed'">
        <xsl:apply-templates select="UNIQUE_KEY/CONSTRAINT">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
      <xsl:if test="UNIQUE_INDEX/@status='changed'">
        <xsl:apply-templates select="UNIQUE_INDEX/INDEX">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="INDEX">
  <xsl:call-template name="display-cmd-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="check-rule">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="srule" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/CHECK_RULE"/>
  <xsl:variable name="rule" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/CHECK_RULE"/>
  <xsl:if test="$srule!=''">
    <dl><dl>
      <li><b>Usage Guidelines and Check Rules:</b></li>
      <ol type="1"><xsl:apply-templates select="$srule/RULE"/></ol>
       <xsl:apply-templates select="$srule/NOTE"/>
    </dl></dl>
  </xsl:if>
  <xsl:if test="not($srule!='') and $rule!=''">
    <dl><dl>
      <li><b>Usage Guidelines and Check Rules:</b></li>
      <ol type="1"><xsl:apply-templates select="$rule/RULE"/></ol>
       <xsl:apply-templates select="$rule/NOTE"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template name="command-type">
  <xsl:if test="COMMAND_TYPE!=''">
    <dl><dl>
      <li><b>Command Type:</b></li>
      <xsl:apply-templates select="COMMAND_TYPE"/>
      <xsl:if test="contains(COMMAND_TYPE,'sync')">
        <xsl:call-template name="caution">
          <xsl:with-param name="type" select="'sync'"/>
        </xsl:call-template>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="COMMAND_TYPE">
  <xsl:call-template name="display-cmd-attr">
    <xsl:with-param name="function" select="'display-cmd-type'"/>
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="display-cmd-type">
  <xsl:for-each select="VERB">
    <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    <xsl:value-of select="current()"/>
  </xsl:for-each>
</xsl:template>

<xsl:template name="upgrade-impact">
  <xsl:if test="$upgradeFile!=''">
    <xsl:variable name="doc" select="document($upgradeFile)"/>
    <xsl:variable name="upgrade" select="$doc/SCHEMA/OWNER/TABLE[@name=current()/@tablename]/UPGRADE_IMPACT"/>
    <xsl:if test="$upgrade!=''">
      <dl><dl><font color="blue">
        <li><b>Upgrade Impact:</b></li>
        <ol type="1"><xsl:apply-templates select="$upgrade/IMPACT"/></ol>
      </font></dl></dl>
    </xsl:if>
  </xsl:if>
</xsl:template>

<xsl:template match="IMPACT">
  <li>
    <xsl:call-template name="break">
      <xsl:with-param name="text" select="current()"/>
    </xsl:call-template>
  </li>
</xsl:template>

<xsl:template name="table-change-history">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="history" select=
     "$mdoc/CLI/NOUN[@name=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@name=current()/@name]/CHANGE_HISTORY|
      $mdoc/CLI/NOUN[@name=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@name=current()/@name]/CHANGE_HISTORY"/>
  <xsl:if test="$history!=''">
    <dl><dl>
      <li><b>Change History:</b></li>
      <xsl:call-template name="display-unformatted-text">
        <xsl:with-param name="text" select="$history"/>
      </xsl:call-template>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template name="display-unformatted-text">
  <xsl:param name="text"/>
  <xsl:if test="$text!=''">
      <xsl:if test="@status!=''">
      <font color="red">
        <dd>
          [<xsl:value-of select="@status"/>]
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$text"/>
          </xsl:call-template>
        </dd>
      </font>
      </xsl:if>
      <xsl:if test="not(@status!='')">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$text"/>
          </xsl:call-template>
        </dd>
      </xsl:if> 
  </xsl:if>
</xsl:template>

<xsl:template match="COLUMN_NAME">
  <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
  <xsl:choose>
    <xsl:when test="FROM_COLUMN!=''">
      <xsl:value-of select="FROM_COLUMN"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="current()"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="TO_COLUMN">
  <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
  <xsl:value-of select="current()"/>
</xsl:template>

<xsl:template match="COMMAND_PARAMETER">
  <div style="margin-left:20px;margin-bottom:1em;font-size:08pt">
    <table border="5" width="95%" style="font-size:08pt" bordercolor="#8080cc" 
           bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
      <thead bgColor='lightgreen'>
        <th width="25%"><b>Token Name</b></th>
        <th><b>Token Description</b></th>
      </thead>
      <xsl:apply-templates select="TOKEN_NAME">
        <xsl:sort select="@varname"/>
      </xsl:apply-templates>
    </table>
  </div>
</xsl:template>

<xsl:template match="TOKEN_NAME">
  <tr bgColor='lightyellow'>
    <td><xsl:value-of select="@varname"/></td>
    <td>
      <table border="0" width="100%" style="font-size:08pt">
        <xsl:call-template name="token-status"/>
        <xsl:call-template name="col-name"/>
        <xsl:call-template name="token-description"/>
        <xsl:call-template name="change-history"/>
        <xsl:apply-templates select="VERB"/>
        <xsl:apply-templates select="REQUIRED"/>
        <xsl:apply-templates select="DEF_VALS"/>
        <xsl:apply-templates select="POS_VALS"/>
        <xsl:apply-templates select="PARSER"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="token-description">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="desc" select=
      "$mdoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION|
       $odoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION|
       $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION|
       $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION"/>
  <xsl:variable name="caution" select=
      "$mdoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION/CAUTION|
       $odoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION/CAUTION|
       $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION/CAUTION|
       $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/DESCRIPTION/CAUTION"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$desc/text()"/>
        </xsl:call-template>
        <xsl:if test="$caution!=''">
          <img src="caution.jpg" width="35" height="30" alt="" border="0" align=""/>
          <b><font color="red"><xsl:value-of select="$caution"/></font></b>
        </xsl:if>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="change-history">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="history" select=
      "$mdoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/CHANGE_HISTORY|
       $odoc/CLI/NOUN[@name=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@varname]/CHANGE_HISTORY|
       $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/CHANGE_HISTORY|
       $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@varname]/CHANGE_HISTORY"/>
  <xsl:if test="$history!=''">
    <tr>
      <td width="150"><b>Change History: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$history"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="token-status">
  <xsl:if test="@status!=''">
    <tr>
      <td width="150"><font color="red"><b>Status: </b></font></td>
      <td><font color="red"><b>
        This token is <xsl:value-of select="@status"/>.
      </b></font></td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="col-name">
  <xsl:if test="COL_NAME!=@varname or COL_NAME/@status!=''">
    <xsl:for-each select="COL_NAME">
      <xsl:call-template name="display-token-attr">
        <xsl:with-param name="item" select="'Column Name'"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template match="VERB">
  <xsl:call-template name="display-token-attr">
    <xsl:with-param name="item" select="'Valid for Command'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="REQUIRED">
  <xsl:call-template name="display-token-attr">
    <xsl:with-param name="item" select="'Mandatory'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="DEF_VALS">
  <xsl:call-template name="display-token-attr">
    <xsl:with-param name="item" select="'Default Value'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="POS_VALS">
  <xsl:call-template name="display-token-attr">
    <xsl:with-param name="item" select="'Possible Value'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="PARSER">
  <xsl:call-template name="display-token-attr">
    <xsl:with-param name="item" select="'Parser'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="display-cmd-attr">
  <xsl:param name="function"/>
  <xsl:param name="status"/>
    <xsl:choose>
    <xsl:when test="$status!=''">
      <dd><font color="red">
        <b>
          <xsl:choose>
          <xsl:when test="@status!=''">
            [<xsl:value-of select="@status"/>]
          </xsl:when>
          <xsl:otherwise>
            [<xsl:value-of select="$status"/>]
          </xsl:otherwise>
          </xsl:choose>
        </b>
        <xsl:call-template name="display-cmd-attr-func">
          <xsl:with-param name="function" select="$function"/>
        </xsl:call-template>
      </font></dd>
    </xsl:when>
    <xsl:otherwise>
      <dd>
        <xsl:call-template name="display-cmd-attr-func">
          <xsl:with-param name="function" select="$function"/>
        </xsl:call-template>
      </dd>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="display-cmd-attr-func">
  <xsl:param name="function"/>
  <xsl:choose>
  <xsl:when test="$function='display-cmd-type'">
    <xsl:call-template name="display-cmd-type"/>
  </xsl:when>
  <xsl:when test="$function='display-containment'">
    <xsl:call-template name="display-containment"/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:call-template name="display-cmd-attr-content"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="display-cmd-attr-content">
  <xsl:text>( </xsl:text>
  <xsl:apply-templates select="COLUMN_NAME"/>
  <xsl:text> )</xsl:text>
  <xsl:if test="COLUMN_NAME/TO_TABLE!=''">
    <xsl:text> references </xsl:text>
    <xsl:value-of select="COLUMN_NAME/TO_TABLE"/>
    <xsl:text> ( </xsl:text>
    <xsl:apply-templates select="COLUMN_NAME/TO_COLUMN"/>
    <xsl:text> )</xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template name="display-token-attr">
  <xsl:param name="item"/>
  <xsl:if test="current()!=''">
    <tr>
      <xsl:choose>
      <xsl:when test="@status!=''">
        <td width="150"><font color="red"><b>
          <xsl:value-of select="$item"/> (<xsl:value-of select="@status"/>):
        </b></font></td>
        <td><font color="red">
          <xsl:call-template name="display-token-attr-content"/>
        </font></td>
      </xsl:when>
      <xsl:otherwise>
        <td width="150"><b><xsl:value-of select="$item"/>:</b></td>
        <td><xsl:call-template name="display-token-attr-content"/></td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="display-token-attr-content">
  <xsl:call-template name="replace-string">
    <xsl:with-param name="text" select="current()"/>
    <xsl:with-param name="replace" select="','"/>
    <xsl:with-param name="with" select="', '"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="replace-string">
  <xsl:param name="text"/>
  <xsl:param name="replace"/>
  <xsl:param name="with"/>
  <xsl:choose>
    <xsl:when test="contains($text,$replace)">
      <xsl:value-of select="substring-before($text,$replace)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-string">
        <xsl:with-param name="text" select="substring-after($text,$replace)"/>
        <xsl:with-param name="replace" select="$replace"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="break">
  <xsl:param name="text"/>
   <xsl:choose>
   <xsl:when test="contains($text, '&#xa;')">
      <xsl:variable name="lineStr" select="substring-before($text,'&#xa;')"/>
      <xsl:value-of select="$lineStr"/>
      <xsl:if test="$lineStr!=''"><br/></xsl:if>
      <xsl:call-template name="break">
          <xsl:with-param name="text" select="substring-after($text,'&#xa;')"/>
      </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
        <xsl:value-of select="$text"/>
   </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<xsl:template name="caution">
  <xsl:param name="type"/>
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:choose>
  <xsl:when test="$type='sync'">
    <xsl:call-template name="display-caution">
      <xsl:with-param name="text"
           select="$mdoc/CLI/GLOBAL/CAUTION/SYNC|$odoc/CLI/GLOBAL/CAUTION/SYNC"/>
    </xsl:call-template>
  </xsl:when>
  </xsl:choose>
</xsl:template>

<xsl:template name="display-caution">
  <xsl:param name="text"/>
  <xsl:if test="$text!=''">
    <dl><br/>
      <b><font color="red">CAUTION! <xsl:value-of select="$text"/></font></b>
    </dl>
  </xsl:if>
</xsl:template>

<xsl:template name="tables-display">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="tables1" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/TABLES"/>
  <xsl:variable name="tables2" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/TABLES"/>
  <xsl:if test="$tables1!=''">
    <xsl:for-each select="$tables1/TABLE"> 
      <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="current()"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:if>
  <xsl:if test="not($tables1!='') and $tables2!=''">
    <xsl:for-each select="$tables2/TABLE"> 
      <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="current()"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template name="table-display">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="table1" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/TABLE"/>
  <xsl:variable name="table2" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/TABLE"/>
  <xsl:if test="$table1!=''">
    <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="$table1"/>
    </xsl:call-template>
  </xsl:if>
  <xsl:if test="not($table1!='') and $table2!=''">
    <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="$table2"/>
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template name="table-display-content">
  <xsl:param name="table"/>
  <xsl:if test="$table!=''">
    <dl><dl>
      <li><b><xsl:value-of select="$table/TITLE"/></b></li>
      <xsl:variable name="desc" select="$table/DESCRIPTION"/>
      <xsl:if test="$desc!=''">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$desc"/>
          </xsl:call-template>
        </dd><br/>
      </xsl:if>
      <table border="1" width="90%" style="font-size:8pt">
        <thead bgColor='lightyellow'>
          <xsl:for-each select="$table/ROW/COLUMN_HEADER">
            <th><b><xsl:value-of select="current()"/></b></th>
          </xsl:for-each>
        </thead>
        <xsl:apply-templates select="$table/ROW"/>
      </table>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="ROW">
  <tr>
  <xsl:for-each select="COLUMN_VALUE">
    <td><xsl:value-of select="current()"/></td>
   </xsl:for-each>
  </tr>
</xsl:template>

</xsl:stylesheet>

