<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:import href="BTS-CLI.xsl"/>

<xsl:template match="CLI">
  <xsl:choose>
  <xsl:when test="$component='all'">
    <xsl:apply-templates select="NOUN[@category='Provisioning']">
     <xsl:sort select="@name"/>
    </xsl:apply-templates>
  </xsl:when>
  <xsl:when test="$component='delta'">
    <xsl:apply-templates select="NOUN[@category='Provisioning' and @status!='']">
     <xsl:sort select="@name"/>
    </xsl:apply-templates>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="NOUN[@name=$component]"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="cmd-token-list">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <b><xsl:value-of select="@name"/></b>
    <xsl:for-each select="COMMAND_PARAMETER/TOKEN_NAME
    	[@varname!='AUTO_REFRESH' and @varname!='DISPLAY' and @varname!='LIMIT' and @varname!='START_ROW' and @varname!='ORDER'
    	and @varname!='LIMIT' and @varname!='PLATFORM_STATE' and @varname!='MASTER' and @varname!='TARGET']">
      <xsl:sort select="@varname"/>
      <xsl:text> </xsl:text>
      <font color="blue"><b>[</b></font>
      <xsl:if test="not(@status!='')">
        <xsl:value-of select="@varname"/>
      </xsl:if>
      <xsl:if test="@status!=''">
        <font color="red"><xsl:value-of select="@varname"/></font>
      </xsl:if>
      <font color="blue"><b>]</b></font>
    </xsl:for-each>
  </div>
</xsl:template>

<xsl:template name="command-type">
  <xsl:if test="COMMAND_TYPE!=''">
    <dl><dl>
      <li><b>Command Type:</b></li>
      <xsl:apply-templates select="COMMAND_TYPE"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template name="display-cmd-type">
  <xsl:for-each select="VERB[text()!='audit' and text()!='sync']">
    <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    <xsl:value-of select="current()"/>
  </xsl:for-each>
</xsl:template>

<xsl:template match="COMMAND_PARAMETER">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
           bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
      <thead bgColor='lightgreen'>
        <th width="25%"><b>Token Name</b></th>
        <th><b>Token Description</b></th>
      </thead>
      <xsl:apply-templates select="TOKEN_NAME
      	[@varname!='AUTO_REFRESH' and @varname!='DISPLAY' and @varname!='LIMIT' and @varname!='START_ROW' and @varname!='ORDER'
    	and @varname!='LIMIT' and @varname!='PLATFORM_STATE' and @varname!='MASTER' and @varname!='TARGET']">
        <xsl:sort select="@varname"/>
      </xsl:apply-templates>
    </table>
  </div>
</xsl:template>

<xsl:template match="VERB">
  <xsl:variable name="item" select="'Valid for Command'"/>
  <xsl:if test="current()!=''">
    <tr>
      <xsl:choose>
      <xsl:when test="@status!=''">
        <td width="150"><font color="red"><b>
          <xsl:value-of select="$item"/> (<xsl:value-of select="@status"/>):
        </b></font></td>
        <td><font color="red">
          <xsl:call-template name="display-verb"/>
        </font></td>
      </xsl:when>
      <xsl:otherwise>
        <td width="150"><b><xsl:value-of select="$item"/>:</b></td>
        <td><xsl:call-template name="display-verb"/></td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="display-verb">
  <xsl:call-template name="replace-verb">
    <xsl:with-param name="text" select="current()"/>
    <xsl:with-param name="replace1" select="',audit'"/>
    <xsl:with-param name="replace2" select="',sync'"/>
    <xsl:with-param name="with" select="''"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="replace-verb">
  <xsl:param name="text"/>
  <xsl:param name="replace1"/>
  <xsl:param name="replace2"/>
  <xsl:param name="with"/>
  <xsl:choose>
    <xsl:when test="contains($text,$replace1)">
      <xsl:value-of select="substring-before($text,$replace1)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-verb">
        <xsl:with-param name="text" select="substring-after($text,$replace1)"/>
        <xsl:with-param name="replace1" select="$replace1"/>
        <xsl:with-param name="replace2" select="$replace2"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="contains($text,$replace2)">
      <xsl:value-of select="substring-before($text,$replace2)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-verb">
        <xsl:with-param name="text" select="substring-after($text,$replace2)"/>
        <xsl:with-param name="replace1" select="$replace1"/>
        <xsl:with-param name="replace2" select="$replace2"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>    
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>

