<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:param name="component">all</xsl:param>
<xsl:param name="locSql">/vob/bts/database/cadmin/create/data/opti_data/OPTI_90S_ca_config_base.sql</xsl:param>
<xsl:param name="locCaDef">/vob/bts/bin/caConfigBase.cfg</xsl:param>
<xsl:param name="locCaHFile">/vob/bts/include/cmn/ca_config_types.h</xsl:param>
<xsl:param name="tabPrefix">CA_CONFIG</xsl:param>
<xsl:param name="codePrefix">CA_CONFIG</xsl:param>
<xsl:param name="definePrefix">CA</xsl:param>

<xsl:template match="/">
  <H3><A href="#1">EMS SQL ( <xsl:value-of select="$locSql"/> )</A></H3>
  <H3><A href="#2">CA Default Value ( <xsl:value-of select="$locCaDef"/> )</A></H3>
  <H3><A href="#3">CA #define ( <xsl:value-of select="$locCaHFile"/> )</A></H3>
  <xsl:call-template name="EMS-SQL"/>
  <xsl:call-template name="CA-default-value"/>
  <xsl:call-template name="CA-include"/>
</xsl:template>

<xsl:template name="EMS-SQL">
  <P/><HR/>
  <H3 id="#1">EMS-SQL ( <xsl:value-of select="$locSql"/> )</H3>
    <xsl:choose>
  <xsl:when test="$component='all'">
    DELETE FROM <xsl:value-of select="$tabPrefix"/>_BASE_POS_VAL;<br/>
    DELETE FROM <xsl:value-of select="$tabPrefix"/>_BASE;<br/>
    <br/>
    <xsl:for-each select="CA_CONFIG/TYPE[not(@status='removed')]">
      <xsl:sort select="@name"/>
      <xsl:call-template name="insert-ca-config"/>
    </xsl:for-each>
    <br/>
    <xsl:for-each select="CA_CONFIG/TYPE[not(@status='removed')]/STRING/VALUE|CA_CONFIG/TYPE[not(@status='removed')]/INTEGER/VALUE">
      <xsl:call-template name="insert-ca-config-pos-val"/>
    </xsl:for-each>    
    <br/>
    COMMIT;<br/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:for-each select="CA_CONFIG/TYPE[@name=$component]">
      <xsl:sort select="@name"/>
      <xsl:call-template name="insert-ca-config"/>
    </xsl:for-each>
    <br/>
    <xsl:for-each select="CA_CONFIG/TYPE[@name=$component]/STRING/VALUE|CA_CONFIG/TYPE[@name=$component]/INTEGER/VALUE">
      <xsl:call-template name="insert-ca-config-pos-val"/>
    </xsl:for-each>    
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="insert-ca-config">
  INSERT INTO <xsl:value-of select="$tabPrefix"/>_BASE values( '<xsl:value-of select="@name"/>',
    <xsl:apply-templates select="STRING|INTEGER|DIGITS|BOOLEAN"/>
    <xsl:apply-templates select="STRING/CHK_POS_VAL"/>
    <xsl:apply-templates select="INTEGER/CHK_POS_VAL"/>
    <xsl:if test="not(STRING/CHK_POS_VAL!='') and not(INTEGER/CHK_POS_VAL!='')">'N',</xsl:if>
    <xsl:call-template name="default-value"/>
    <xsl:apply-templates select="FOREIGN_KEY"/>
    <xsl:if test="not(FOREIGN_KEY!='')">NULL,NULL</xsl:if>
  );<br/>
</xsl:template>

<xsl:template name="insert-ca-config-pos-val">
  INSERT INTO <xsl:value-of select="$tabPrefix"/>_BASE_POS_VAL values( '<xsl:value-of select="../../@name"/>',
    '<xsl:value-of select="current()"/>'
  );<br/>
</xsl:template>

<xsl:template name="CA-default-value">
  <P/><HR/>
  <H3 id="#2">CA Default Value ( <xsl:value-of select="$locCaDef"/> )</H3>
  <table border="0" width="95%" style="font-size:8pt">
    <xsl:choose>
    <xsl:when test="$component='all'">
      <tr><td>
        ########################################################################################<br/>
	    ###<br/>
	    ### No changes should be made to this file. DO NOT HAND EDIT !!<br/>
	    ### Erratic system behavior will result. Contact Cisco BTS Support for assistance.<br/>
	    ### Copyright (c) 2004-2008 by Cisco Systems, Inc.<br/>
	    ### CONFIG BASE<br/>
	    ###<br/>
	    ### FORMAT: PARMERTER NAME DATATYPE(1--BOOLEAN, 2--INTEGER, 3--STRING, 4--DIGITS) VALUE<br/>
	    ###<br/>
	    ########################################################################################<br/>
	    <br/>
      </td></tr>
      <xsl:for-each select="CA_CONFIG/TYPE[not(@status='removed')]">
        <xsl:sort select="@name"/>
        <tr><xsl:call-template name="create-ca-default-value"/></tr>
      </xsl:for-each>
    </xsl:when>
    <xsl:otherwise>
      <xsl:for-each select="CA_CONFIG/TYPE[@name=$component]">
        <tr><xsl:call-template name="create-ca-default-value"/></tr>
      </xsl:for-each>
    </xsl:otherwise>
    </xsl:choose>
  </table>
</xsl:template>

<xsl:template name="create-ca-default-value">
  <td width="40%"><xsl:value-of select="@name"/></td>
  <td width="10%">
    <xsl:if test="BOOLEAN">1</xsl:if>
    <xsl:if test="INTEGER">2</xsl:if>
    <xsl:if test="STRING">3</xsl:if>
    <xsl:if test="DIGITS">4</xsl:if>
  </td>
  <td>
    <xsl:choose>
    <xsl:when test="DEFAULT_VALUE!=''">
      <xsl:value-of select="DEFAULT_VALUE"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>NULL</xsl:text>
    </xsl:otherwise>
    </xsl:choose>
  </td>
</xsl:template>

<xsl:template name="CA-include">
  <P/><HR/>
  <H3 id="#3">CA #define ( <xsl:value-of select="$locCaHFile"/> )</H3>
  <table border="0" width="95%" style="font-size:8pt">
    <xsl:choose>
    <xsl:when test="$component='all'">
      <tr><td>
        /*<br/>
	     * This file is automatically generated!! DO NOT HAND EDIT!!<br/>
	     * Copyright (c) 2004-2008 by Cisco Systems, Inc.<br/>
	     */<br/>
	    <br/>
      </td></tr>
      <tr><td>
        #ifndef     __<xsl:value-of select="$codePrefix"/>_TYPES_H__<br/>
        #define     __<xsl:value-of select="$codePrefix"/>_TYPES_H__<br/>
        <br/>
        #ifdef  __cplusplus<br/>
        extern  "C" {<br/>
        #endif<br/>
      </td></tr>
      <xsl:for-each select="CA_CONFIG/TYPE[not(@status='removed')]">
        <xsl:sort select="@name"/>
	    <tr><xsl:call-template name="create-ca-include"/></tr>
      </xsl:for-each>
      <tr><td>
        <br/>
        #ifdef  __cplusplus<br/>
        }<br/>
        #endif<br/>
        <br/>
        #endif  __<xsl:value-of select="$codePrefix"/>_TYPES_H__<br/>
      </td></tr>
    </xsl:when>
    <xsl:otherwise>
      <xsl:for-each select="CA_CONFIG/TYPE[@name=$component]">
        <tr><xsl:call-template name="create-ca-include"/></tr>
      </xsl:for-each>
    </xsl:otherwise>
    </xsl:choose>

  </table>
</xsl:template>

<xsl:template name="create-ca-include">
  <td width="50%">
    <xsl:text>#define </xsl:text><xsl:value-of select="$definePrefix"/><xsl:text>_CON_</xsl:text>
    <xsl:value-of select="translate(@name,'-','_')"/>
  </td>
  <td>
    "<xsl:value-of select="translate(@name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>"
  </td>
</xsl:template>

<xsl:template match="STRING">
  'STRING',NULL,NULL,
</xsl:template>

<xsl:template match="INTEGER">
  <xsl:choose>
  <xsl:when test="FROM_VALUE!=''">
    'INTEGER','<xsl:value-of select="FROM_VALUE"/>','<xsl:value-of select="TO_VALUE"/>',
  </xsl:when>
  <xsl:otherwise>
    'INTEGER',NULL,NULL,
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="DIGITS">
  <xsl:choose>
  <xsl:when test="FROM_VALUE!=''">
    'DIGITS','<xsl:value-of select="FROM_VALUE"/>','<xsl:value-of select="TO_VALUE"/>',
  </xsl:when>
  <xsl:otherwise>
    'DIGITS',NULL,NULL,
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="BOOLEAN">
  'BOOLEAN',NULL,NULL,
</xsl:template>

<xsl:template match="FOREIGN_KEY">
  <xsl:choose>
  <xsl:when test="TABLENAME!=''">
    '<xsl:value-of select="TABLENAME"/>','<xsl:value-of select="TOKENNAME"/>'
  </xsl:when>
  <xsl:otherwise>
    NULL,NULL
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="default-value">
  <xsl:choose>
  <xsl:when test="DEFAULT_VALUE!=''">
    '<xsl:value-of select="DEFAULT_VALUE"/>',
  </xsl:when>
  <xsl:otherwise>
    NULL,
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="CHK_POS_VAL">
  '<xsl:value-of select="current()"/>',
</xsl:template>

</xsl:stylesheet>

