<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:import href="BTS-CLI.xsl"/>

<xsl:template match="CLI">
  <xsl:choose>
  <xsl:when test="$component='all'">
    <xsl:if test="$category='all' or not($category!='')">
      <xsl:apply-templates select="NOUN[@status!='']">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="not($category='all' or not($category!=''))">
      <xsl:apply-templates select="NOUN[@status!='' and @category=$category]">
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="NOUN[@name=$component]"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="NOUN">
  <xsl:variable name="fullname" select="FULL_NAME"/>
  <font size="3">
  <H3>Command Name = <xsl:value-of select="@name"/>
    <xsl:if test="$fullname!=''">
      (<xsl:value-of select="$fullname"/>)
    </xsl:if>
    <xsl:if test="@status!=''">
      <font color="red"> (<xsl:value-of select="@status"/>)</font>
    </xsl:if>
  </H3>
  </font>
  <xsl:if test="@tablename!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <font size="3">
      <H4>Table Name = <xsl:value-of select="@tablename"/></H4>
      </font>
    </div>
  </xsl:if>
  <xsl:call-template name="cmd-description"/>
  <xsl:call-template name="cmd-token-list"/>
  <xsl:apply-templates select="CONTAINMENT"/>
  <xsl:apply-templates select="PRIMARY_KEY"/>
  <xsl:apply-templates select="FOREIGN_KEY"/>
  <xsl:apply-templates select="UNIQUE_KEY"/>
  <xsl:apply-templates select="AVL_TREE"/>
  <xsl:call-template name="check-rule"/>
  <xsl:apply-templates select="COMMAND_TYPE"/>
  <xsl:call-template name="example"/>
  <xsl:apply-templates select="TABLES"/>
  <xsl:apply-templates select="TABLE"/>
  <xsl:call-template name="upgrade-impact"/>
  <xsl:apply-templates select="CHANGE_HISTORY"/>
  <xsl:apply-templates select="COMMAND_PARAMETER"/>
</xsl:template>

<xsl:template name="cmd-description">
  <xsl:variable name="desc" select="DESCRIPTION"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <xsl:if test="DESCRIPTION/@status!=''">
      <font color="red">
      [<xsl:value-of select="@status"/>]
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="$desc/text()"/>
      </xsl:call-template>
      <xsl:apply-templates select="$desc/CAUTION"/>
      </font>
    </xsl:if>
    <xsl:if test="not(DESCRIPTION/@status!='')">
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="$desc/text()"/>
      </xsl:call-template>
      <xsl:apply-templates select="$desc/CAUTION"/>
    </xsl:if>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template match="CHANGE_HISTORY">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Change History:</b></li>
      <xsl:call-template name="display-unformatted-text"/>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template match="CONTAINMENT">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Containment Area:</b></li>
      <xsl:call-template name="display-text"/>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template match="PRIMARY_KEY">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Primary Key:</b></li>
      <xsl:call-template name="display-text"/>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template match="FOREIGN_KEY">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Foreign Key:</b></li>
      <ol type="1"><xsl:apply-templates select="CONSTRAINT"/></ol>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="UNIQUE_KEY">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Unique Key:</b></li>
      <ol type="1"><xsl:apply-templates select="CONSTRAINT"/></ol>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="AVL_TREE">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>AVL Tree:</b></li>
      <ol type="1"><xsl:apply-templates select="AVL_KEY"/></ol>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="COMMAND_TYPE">
  <xsl:if test="current()!=''">
    <dl><dl>
      <li><b>Command Type:</b></li>
      <xsl:call-template name="display-text"/>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template name="display-text">
  <xsl:if test="current()!=''">
      <xsl:if test="@status!=''">
      <font color="red">
        <dd>
          [<xsl:value-of select="@status"/>]
          <xsl:if test="@remark!=''">
            [<xsl:value-of select="@remark"/>]
          </xsl:if>
          <xsl:value-of select="current()"/>
        </dd>
      </font>
      </xsl:if>
      <xsl:if test="not(@status!='')">
        <dd><xsl:value-of select="current()"/></dd>
      </xsl:if> 
  </xsl:if>
</xsl:template>

<xsl:template name="display-unformatted-text">
  <xsl:if test="current()!=''">
      <xsl:if test="@status!=''">
      <font color="red">
        <dd>
          [<xsl:value-of select="@status"/>]
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="current()"/>
          </xsl:call-template>
        </dd>
      </font>
      </xsl:if>
      <xsl:if test="not(@status!='')">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="current()"/>
          </xsl:call-template>
        </dd>
      </xsl:if> 
  </xsl:if>
</xsl:template>

<xsl:template name="check-rule">
  <xsl:variable name="rule" select="CHECK_RULE"/>
  <xsl:if test="$rule!=''">
    <dl><dl>
      <li><b>Usage Guidelines and Check Rules:</b></li>
      <ol type="1"><xsl:apply-templates select="$rule/RULE"/></ol>
      <xsl:apply-templates select="$rule/NOTE"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="RULE|STATEMENT|CONSTRAINT|IMPACT|AVL_KEY">
  <xsl:if test="@status!=''">
    <font color="red">
      <li>
        [<xsl:value-of select="@status"/>]
        <xsl:if test="@remark!=''">
          [<xsl:value-of select="@remark"/>]
        </xsl:if>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="current()"/>
        </xsl:call-template>
      </li>
    </font>
  </xsl:if>
  <xsl:if test="not(@status!='')">
    <li>
      <xsl:if test="@remark!=''">
        [<xsl:value-of select="@remark"/>]
      </xsl:if>
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="current()"/>
      </xsl:call-template>
    </li>
  </xsl:if>
</xsl:template>

<xsl:template match="EXAMPLE_NOTE|NOTE">
   <xsl:if test="@status!=''">
     <font color="red">
       <br/><dl>
         <b>Note: </b>
         [<xsl:value-of select="@status"/>]
         <xsl:if test="@remark!=''">
           [<xsl:value-of select="@remark"/>]
         </xsl:if>
         <xsl:value-of select="current()"/>
       </dl>
     </font>
   </xsl:if>
   <xsl:if test="not(@status!='')">
     <br/><dl>
       <b>Note: </b>
       <xsl:if test="@remark!=''">
         [<xsl:value-of select="@remark"/>]
       </xsl:if>
       <xsl:value-of select="current()"/>
     </dl>
   </xsl:if>
</xsl:template>

<xsl:template name="example">
  <xsl:variable name="example" select="EXAMPLE"/>
  <xsl:if test="$example!=''">
    <dl><dl>
      <li><b>Examples:</b></li>
      <ol type="1"><xsl:apply-templates select="$example/STATEMENT"/></ol>
      <xsl:apply-templates select="$example/EXAMPLE_NOTE"/>
      <xsl:if test="$example/CAUTION!=''">
        <xsl:call-template name="display-caution">
          <xsl:with-param name="text" select="$example/CAUTION"/>
        </xsl:call-template>
      </xsl:if>     
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template name="upgrade-impact-notused">
  <xsl:variable name="upgrade" select="UPGRADE_IMPACT"/>
  <xsl:if test="$upgrade!=''">
    <dl><dl><font color="blue">
      <li><b>Upgrade Impact:</b></li>
      <ol type="1"><xsl:apply-templates select="$upgrade/IMPACT"/></ol>
    </font></dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="COMMAND_PARAMETER">
  <xsl:if test="../@status='new' or ../@status='removed' or ../@status='pending' or TOKEN_NAME/@status!=''">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
           bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
      <thead bgColor='lightgreen'>
        <th width="25%"><b>Token Name</b></th>
        <th><b>Token Description</b></th>
      </thead>
      <xsl:choose>
      <xsl:when test="../@status='changed'">
        <xsl:apply-templates select="TOKEN_NAME[@status!='']">
          <xsl:sort select="@varname"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="TOKEN_NAME">
          <xsl:sort select="@varname"/>
        </xsl:apply-templates>
      </xsl:otherwise>
      </xsl:choose>
    </table>
  </div>
  </xsl:if>
</xsl:template>

<xsl:template match="TOKEN_NAME">
  <tr bgColor='lightyellow'>
    <td><xsl:value-of select="@varname"/></td>
    <td>
      <table border="0" width="100%" style="font-size:08pt">
        <xsl:call-template name="token-status"/>      
        <xsl:call-template name="col-name"/>
        <xsl:call-template name="token-description"/>
        <xsl:call-template name="data-type"/>
        <xsl:call-template name="change-history"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="token-phase">
  <xsl:if test="@phase!=''">   
    <font color="red">
      Changes are last made in phase: <xsl:value-of select="@phase"/>.
    </font>
  </xsl:if>
</xsl:template>

<xsl:template name="col-name">
  <xsl:if test="COL_NAME!=@varname or COL_NAME/@status!=''">
    <tr>
      <xsl:if test="COL_NAME/@status!=''">
        <td width="150"><font color="red"><b>Column Name: </b></font></td>
      </xsl:if>
      <xsl:if test="not(COL_NAME/@status!='')">
        <td width="150"><font color="blue"><b>Column Name: </b></font></td>
      </xsl:if>
      <td>
      <font color="red"><b>
        Column Name: <xsl:value-of select="COL_NAME"/>
      </b></font>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="token-description">
  <xsl:variable name="desc" select="DESCRIPTION"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$desc"/>
        </xsl:call-template>
        <xsl:apply-templates select="$desc/CAUTION"/>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="data-type">
  <xsl:if test="DATA_TYPE!=''">
    <tr>
      <td width="150"><b>Data Type: </b></td>
       <td>
         <xsl:if test="@status!=''">
           <font color="red">
             <xsl:apply-templates select="DATA_TYPE"/>
           </font>
         </xsl:if>
         <xsl:if test="not(@status!='')">
           <xsl:apply-templates select="DATA_TYPE"/>
         </xsl:if>
       </td>
    </tr>
  </xsl:if>
</xsl:template>
        
<xsl:template match="DATA_TYPE">
  <xsl:value-of select="current()"/><br/>
  <xsl:if test="@mandatory!=''">
    Mandatory: <xsl:value-of select="@mandatory"/><br/>
  </xsl:if>
  <xsl:if test="@default!=''">
    Default: <xsl:value-of select="@default"/><br/>
  </xsl:if>
  <xsl:if test="@parser!=''">
    Parser: <xsl:value-of select="@parser"/><br/>
  </xsl:if>
  <xsl:if test="@possible_value!=''">
    Possible Value: <xsl:value-of select="@possible_value"/><br/>
  </xsl:if>
</xsl:template>

<xsl:template name="change-history">
  <xsl:variable name="history" select="CHANGE_HISTORY"/>
  <xsl:if test="($history!='' or @phase!='')">
    <tr>
      <td width="150"><b>Change History: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$history"/>
        </xsl:call-template>
        <xsl:call-template name="token-phase"/>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template match="TABLES">
  <xsl:apply-templates select="TABLE"/>
</xsl:template>

<xsl:template match="TABLE">
  <xsl:call-template name="table-display">
    <xsl:with-param name="table" select="current()"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="table-display">
  <xsl:param name="table"/>
  <xsl:if test="$table!=''">
    <dl><dl>
      <li><b><xsl:value-of select="$table/TITLE"/></b></li>
      <xsl:variable name="desc" select="$table/DESCRIPTION"/>
      <xsl:if test="$desc!=''">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$desc"/>
          </xsl:call-template>
        </dd><br/>
      </xsl:if>
      <table border="1" width="90%" style="font-size:8pt">
        <thead bgColor='lightyellow'>
          <xsl:for-each select="$table/ROW/COLUMN_HEADER">
            <th><b><xsl:value-of select="current()"/></b></th>
          </xsl:for-each>
        </thead>
        <xsl:apply-templates select="$table/ROW"/>
      </table>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="ROW">
  <tr>
    <xsl:if test="@status!=''">
      <xsl:for-each select="COLUMN_VALUE">
        <td bgColor='pink'><font color="red"><xsl:value-of select="current()"/></font></td>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="not(@status!='')">
      <xsl:for-each select="COLUMN_VALUE">
        <td><xsl:value-of select="current()"/></td>
      </xsl:for-each>
    </xsl:if>
  </tr>
</xsl:template>

</xsl:stylesheet>

