<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:param name="component">all</xsl:param>
<xsl:param name="oDescFile"></xsl:param>
<xsl:param name="mDescFile"></xsl:param>
<xsl:param name="upgradeFile"></xsl:param>
<xsl:param name="category"></xsl:param>

<xsl:template match="/">
  <xsl:apply-templates select="SCHEMA"/>
</xsl:template>

<xsl:template match="SCHEMA">
  <xsl:choose>
  <xsl:when test="$component='all'">
    <xsl:if test="$category='all'">
      <xsl:apply-templates select="OWNER/TABLE">
       <xsl:sort select="../@name"/>
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="not($category='all')">
      <xsl:apply-templates select="OWNER[@name=$category]/TABLE">
       <xsl:sort select="../@name"/>
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:when>
  <xsl:when test="$component='delta'">
    <xsl:if test="$category='all'">
      <xsl:apply-templates select="OWNER/TABLE[@status!='']">
       <xsl:sort select="../@name"/>
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="not($category='all')">
      <xsl:apply-templates select="OWNER[@name=$category]/TABLE[@status!='']">
       <xsl:sort select="../@name"/>
       <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates select="OWNER/TABLE[@name=$component]"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="TABLE">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="fullname" select=
       "$mdoc/CLI/NOUN[@name=current()/@name]/FULL_NAME|
        $odoc/CLI/NOUN[@name=current()/@name]/FULL_NAME"/>
  <font size="3">
  <H3>Table Name = <xsl:value-of select="../@name"/>.<xsl:value-of select="@name"/>
    <xsl:if test="$fullname!=''">
      (<xsl:value-of select="$fullname"/>)
    </xsl:if>
    <xsl:if test="@status!=''">
      <font color="red"> (<xsl:value-of select="@status"/>)</font>
    </xsl:if>
  </H3>
  </font>
  <xsl:call-template name="table-description"/>
  <xsl:call-template name="table-column-list"/>
  <xsl:call-template name="containment"/>
  <xsl:call-template name="primary-key"/>
  <xsl:call-template name="foreign-key"/>
  <xsl:call-template name="child-foreign-key"/>
  <xsl:call-template name="unique-key"/>
  <xsl:call-template name="check-constraint"/>
  <xsl:call-template name="check-rule"/>
  <xsl:call-template name="tables-display"/>
  <xsl:call-template name="table-display"/>
  <xsl:call-template name="nonunique-index"/>
  <xsl:call-template name="upgrade-impact"/>
  <xsl:call-template name="table-change-history"/>
  <xsl:apply-templates select="COLUMN_DEFINITION"/>
</xsl:template>

<xsl:template name="table-description">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="desc" select=
      "$mdoc/CLI/NOUN[@tablename=current()/@name]/DESCRIPTION|
       $odoc/CLI/NOUN[@tablename=current()/@name]/DESCRIPTION"/>
  <xsl:variable name="caution" select=
      "$mdoc/CLI/NOUN[@tablename=current()/@name]/DESCRIPTION/CAUTION|
       $odoc/CLI/NOUN[@tablename=current()/@name]/DESCRIPTION/CAUTION"/>
  <xsl:if test="$desc!=''">
    <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
      <xsl:call-template name="break">
        <xsl:with-param name="text" select="$desc/text()"/>
      </xsl:call-template>
      <xsl:if test="$caution!=''">
        <img src="caution.jpg" width="35" height="30" alt="" border="0" align=""/>
        <b><font color="red"><xsl:value-of select="$caution"/></font></b>
      </xsl:if>
    </div>
  </xsl:if>
</xsl:template>

<xsl:template name="table-column-list">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <b><xsl:value-of select="@name"/></b>
    <xsl:for-each select="COLUMN_DEFINITION/COLUMN">
      <xsl:sort select="@name"/>
      <xsl:text> </xsl:text>
      <font color="blue"><b>[</b></font>
      <xsl:if test="not(@status!='')">
        <xsl:value-of select="@name"/>
      </xsl:if>
      <xsl:if test="@status!=''">
        <font color="red"><xsl:value-of select="@name"/></font>
      </xsl:if>
      <font color="blue"><b>]</b></font>
    </xsl:for-each>
  </div>
</xsl:template>

<xsl:template name="containment">
  <xsl:if test="CONTAINMENT!=''">
    <dl><dl>
      <li><b>Containment Area:</b></li>
      <xsl:apply-templates select="CONTAINMENT"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CONTAINMENT">
  <xsl:call-template name="display-table-attr">
    <xsl:with-param name="function" select="'display-containment'"/>
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="display-containment">
  <xsl:for-each select="AREA">
    <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
    <xsl:value-of select="current()"/>
  </xsl:for-each>
</xsl:template>

<xsl:template name="primary-key">
  <xsl:if test="PRIMARY_KEY!=''">
    <dl><dl>
      <li><b>Primary Key:</b></li>
      <xsl:apply-templates select="PRIMARY_KEY"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="PRIMARY_KEY">
  <xsl:call-template name="display-table-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="foreign-key">
  <xsl:if test="FOREIGN_KEY!=''">
    <dl><dl>
      <li><b>Foreign Key:</b></li>
      <xsl:if test="not(FOREIGN_KEY/@status='changed')">
        <xsl:for-each select="FOREIGN_KEY/CONSTRAINT">
          <xsl:call-template name="display-table-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="FOREIGN_KEY/@status='changed'">
        <xsl:apply-templates select="FOREIGN_KEY/CONSTRAINT">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CONSTRAINT">
  <xsl:call-template name="display-table-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="child-foreign-key">
  <xsl:if test="CHILD_FOREIGN_KEY!=''">
    <dl><dl>
      <li><b>Child Foreign Key:</b></li>
      <xsl:if test="not(CHILD_FOREIGN_KEY/@status='changed')">
        <xsl:for-each select="CHILD_FOREIGN_KEY/CONSTRAINT">
          <xsl:call-template name="display-table-attr">
            <xsl:with-param name="function" select="'display-child-foreign-key'"/>
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="CHILD_FOREIGN_KEY/@status='changed'">
        <xsl:apply-templates select="CHILD_FOREIGN_KEY"/>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CHILD_FOREIGN_KEY">
  <xsl:for-each select="CONSTRAINT">
   <xsl:sort select="@status"/>
    <xsl:call-template name="display-table-attr">
      <xsl:with-param name="function" select="'display-child-foreign-key'"/>
      <xsl:with-param name="status" select="@status"/>
    </xsl:call-template>
  </xsl:for-each>
</xsl:template>

<xsl:template name="unique-key">
  <xsl:if test="UNIQUE_KEY!='' or UNIQUE_INDEX!=''">
    <dl><dl>
      <li><b>Unique Key:</b></li>
      <xsl:if test="not(UNIQUE_KEY/@status='changed')">
        <xsl:for-each select="UNIQUE_KEY/CONSTRAINT">
          <xsl:call-template name="display-table-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="not(UNIQUE_INDEX/@status='changed')">
        <xsl:for-each select="UNIQUE_INDEX/INDEX">
          <xsl:call-template name="display-table-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="UNIQUE_KEY/@status='changed'">
        <xsl:apply-templates select="UNIQUE_KEY/CONSTRAINT">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
      <xsl:if test="UNIQUE_INDEX/@status='changed'">
        <xsl:apply-templates select="UNIQUE_INDEX/INDEX">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="INDEX">
  <xsl:call-template name="display-table-attr">
    <xsl:with-param name="status" select="@status"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="nonunique-index">
  <xsl:if test="NONUNIQUE_INDEX!=''">
    <dl><dl>
      <li><b>Index:</b></li>
      <xsl:if test="not(NONUNIQUE_INDEX/@status='changed')">
        <xsl:for-each select="NONUNIQUE_INDEX/INDEX">
          <xsl:call-template name="display-table-attr">
            <xsl:with-param name="status" select="../@status"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="NONUNIQUE_INDEX/@status='changed'">
        <xsl:apply-templates select="NONUNIQUE_INDEX/INDEX">
          <xsl:sort select="@status"/>
        </xsl:apply-templates>
      </xsl:if>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template name="check-constraint">
  <xsl:if test="CHECK_CONSTRAINT!=''">
    <dl><dl>
      <li><b>Check Constraint:</b></li>
      <xsl:apply-templates select="CHECK_CONSTRAINT"/>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="CHECK_CONSTRAINT">
  <xsl:for-each select="RULE">
   <xsl:sort select="@status"/>
    <xsl:call-template name="display-table-attr">
      <xsl:with-param name="function" select="'display-check-constraint'"/>
      <xsl:with-param name="status" select="@status"/>
    </xsl:call-template>
  </xsl:for-each>
</xsl:template>

<xsl:template name="check-rule">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="srule" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/CHECK_RULE"/>
  <xsl:variable name="rule" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/CHECK_RULE"/>
  <xsl:if test="$srule!=''">
    <dl><dl>
      <li><b>Usage Guidelines and Check Rules:</b></li>
      <ol type="1"><xsl:apply-templates select="$srule/RULE"/></ol>
    </dl></dl>
  </xsl:if>
  <xsl:if test="not($srule!='') and $rule!=''">
    <dl><dl>
      <li><b>Usage Guidelines and Check Rules:</b></li>
      <ol type="1"><xsl:apply-templates select="$rule/RULE"/></ol>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="RULE">
  <li>
    <xsl:call-template name="break">
      <xsl:with-param name="text" select="current()"/>
    </xsl:call-template>
  </li>
</xsl:template>

<xsl:template name="upgrade-impact">
  <xsl:if test="$upgradeFile!=''">
    <xsl:variable name="doc" select="document($upgradeFile)"/>
    <xsl:variable name="upgrade" select="$doc/SCHEMA/OWNER/TABLE[@name=current()/@name]/UPGRADE_IMPACT"/>
    <xsl:if test="$upgrade!=''">
      <dl><dl><font color="blue">
        <li><b>Upgrade Impact:</b></li>
        <ol type="1"><xsl:apply-templates select="$upgrade/IMPACT"/></ol>
      </font></dl></dl>
    </xsl:if>
  </xsl:if>
</xsl:template>

<xsl:template match="IMPACT">
  <li>
    <xsl:call-template name="break">
      <xsl:with-param name="text" select="current()"/>
    </xsl:call-template>
  </li>
</xsl:template>

<xsl:template name="table-change-history">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="history" select=
     "$mdoc/CLI/NOUN[@tablename=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@tablename=current()/@name]/CHANGE_HISTORY|
      $mdoc/CLI/NOUN[@tablename=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@tablename=current()/@name]/CHANGE_HISTORY"/>
  <xsl:if test="$history!=''">
    <dl><dl>
      <li><b>Change History:</b></li>
      <xsl:call-template name="display-unformatted-text">
        <xsl:with-param name="text" select="$history"/>
      </xsl:call-template>
    </dl></dl>  
  </xsl:if>  
</xsl:template>

<xsl:template name="display-unformatted-text">
  <xsl:param name="text"/>
  <xsl:if test="$text!=''">
      <xsl:if test="@status!=''">
      <font color="red">
        <dd>
          [<xsl:value-of select="@status"/>]
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$text"/>
          </xsl:call-template>
        </dd>
      </font>
      </xsl:if>
      <xsl:if test="not(@status!='')">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$text"/>
          </xsl:call-template>
        </dd>
      </xsl:if> 
  </xsl:if>
</xsl:template>

<xsl:template match="COLUMN_NAME">
  <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
  <xsl:choose>
    <xsl:when test="FROM_COLUMN!=''">
      <xsl:value-of select="FROM_COLUMN"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="current()"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="TO_COLUMN">
  <xsl:if test="position()!=1"> <xsl:text>, </xsl:text> </xsl:if>
  <xsl:value-of select="current()"/>
</xsl:template>

<xsl:template match="COLUMN_DEFINITION">
  <div style="margin-left:20px;margin-bottom:1em;font-size:8pt">
    <table border="5" width="95%" style="font-size:8pt" bordercolor="#8080cc" 
           bordercolorlight="#8080c0" bordercolordark="#400080" bgcolor="#ffffcc">
      <thead bgColor='lightgreen'>
        <th width="25%"><b>Column Name</b></th>
        <th><b>Column Description</b></th>
      </thead>
      <xsl:for-each select="COLUMN">
       <xsl:sort select="@name"/>
        <xsl:call-template name="display-column"/>
      </xsl:for-each>
    </table>
  </div>
</xsl:template>

<xsl:template name="display-column">
  <tr bgColor='lightyellow'>
    <td><xsl:value-of select="@name"/></td>
    <td>
      <table border="0" width="100%" style="font-size:8pt">
        <xsl:call-template name="column-status"/>
        <xsl:call-template name="column-description"/>
        <xsl:call-template name="change-history"/>
        <xsl:apply-templates select="DATA_TYPE"/>
        <xsl:apply-templates select="NULLABLE"/>
        <xsl:apply-templates select="DATA_DEFAULT"/>
        <xsl:apply-templates select="CHECK"/>
        <xsl:apply-templates select="COMMENTS"/>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="column-description">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="desc" select=
     "$mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION|
      $mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION|
      $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION|
      $odoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION"/>
  <xsl:variable name="caution" select=
     "$mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION/CAUTION|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION/CAUTION|
      $mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION/CAUTION|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION/CAUTION|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION/CAUTION|
      $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/DESCRIPTION/CAUTION|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION/CAUTION|
      $odoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/DESCRIPTION/CAUTION"/>
  <xsl:if test="$desc!=''">
    <tr>
      <td width="150"><b>Description: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$desc/text()"/>
        </xsl:call-template>
        <xsl:if test="$caution!=''">
          <img src="caution.jpg" width="35" height="30" alt="" border="0" align=""/>
          <b><font color="red"><xsl:value-of select="$caution"/></font></b>
        </xsl:if>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="change-history">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="history" select=
     "$mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[@varname=current()/@name]/CHANGE_HISTORY|
      $mdoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/NOUN[@tablename=current()/../../@name]/COMMAND_PARAMETER/TOKEN_NAME[COL_NAME=current()/@name]/CHANGE_HISTORY|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/GLOBAL/TOKEN_NAME[@varname=current()/@name]/CHANGE_HISTORY|
      $mdoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/CHANGE_HISTORY|
      $odoc/CLI/GLOBAL/TOKEN_NAME[COL_NAME=current()/@name]/CHANGE_HISTORY"/>
  <xsl:if test="$history!=''">
    <tr>
      <td width="150"><b>Change History: </b></td>
      <td>
        <xsl:call-template name="break">
          <xsl:with-param name="text" select="$history"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="column-status">
  <xsl:if test="@status!=''">
    <tr>
      <td width="150"><font color="red"><b>Status: </b></font></td>
      <td><font color="red"><b>
        This column is <xsl:value-of select="@status"/>.
      </b></font></td>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template match="DATA_TYPE">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Data Type'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="NULLABLE">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Nullable'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="DATA_DEFAULT">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Default Value'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="CHECK">
  <xsl:for-each select="RULE">
    <xsl:call-template name="display-column-attr">
      <xsl:with-param name="item" select="'Check Rule'"/>
      <xsl:with-param name="status" select="../@status"/>
    </xsl:call-template>
  </xsl:for-each>
</xsl:template>

<xsl:template match="COMMENTS">
  <xsl:call-template name="display-column-attr">
    <xsl:with-param name="item" select="'Comments'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="display-table-attr">
  <xsl:param name="function"/>
  <xsl:param name="status"/>
    <xsl:choose>
    <xsl:when test="$status!=''">
      <dd><font color="red">
        <b>
          <xsl:choose>
          <xsl:when test="@status!=''">
            [<xsl:value-of select="@status"/>]
          </xsl:when>
          <xsl:otherwise>
            [<xsl:value-of select="$status"/>]
          </xsl:otherwise>
          </xsl:choose>
        </b>
        <xsl:call-template name="display-table-attr-func">
          <xsl:with-param name="function" select="$function"/>
        </xsl:call-template>
      </font></dd>
    </xsl:when>
    <xsl:otherwise>
      <dd>
        <xsl:call-template name="display-table-attr-func">
          <xsl:with-param name="function" select="$function"/>
        </xsl:call-template>
      </dd>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="display-table-attr-func">
  <xsl:param name="function"/>
  <xsl:choose>
  <xsl:when test="$function='display-child-foreign-key'">
    <xsl:call-template name="display-child-foreign-key"/>
  </xsl:when>
  <xsl:when test="$function='display-containment'">
    <xsl:call-template name="display-containment"/>
  </xsl:when>
  <xsl:when test="$function='display-check-constraint'">
    <xsl:call-template name="display-check-constraint"/>
  </xsl:when>
  <xsl:otherwise>
    <xsl:call-template name="display-table-attr-content"/>
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="display-table-attr-content">
  <xsl:text>( </xsl:text>
  <xsl:apply-templates select="COLUMN_NAME"/>
  <xsl:text> )</xsl:text>
  <xsl:if test="COLUMN_NAME/TO_TABLE!=''">
    <xsl:text> references </xsl:text>
    <xsl:value-of select="COLUMN_NAME/TO_TABLE"/>
    <xsl:text> ( </xsl:text>
    <xsl:apply-templates select="COLUMN_NAME/TO_COLUMN"/>
    <xsl:text> )</xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template name="display-child-foreign-key">
  <xsl:value-of select="COLUMN_NAME/FROM_TABLE"/>
  <xsl:text> ( </xsl:text>
  <xsl:apply-templates select="COLUMN_NAME"/>
  <xsl:text> )</xsl:text>
  <xsl:text> references </xsl:text>
  <xsl:text>( </xsl:text>
  <xsl:apply-templates select="COLUMN_NAME/TO_COLUMN"/>
  <xsl:text> )</xsl:text>
</xsl:template>

<xsl:template name="display-check-constraint">
  <xsl:value-of select="current()"/>
</xsl:template>

<xsl:template name="display-column-attr">
  <xsl:param name="item"/>
  <xsl:param name="status"/>
  <xsl:if test="current()!=''">
    <tr>
      <xsl:choose>
      <xsl:when test="$status!='' or @status!=''">
        <td width="150"><font color="red"><b>
          <xsl:choose>
          <xsl:when test="@status!=''">
            <xsl:value-of select="$item"/> (<xsl:value-of select="@status"/>):
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$item"/> (<xsl:value-of select="$status"/>):
          </xsl:otherwise>
          </xsl:choose>
        </b></font></td>
        <td><font color="red">
          <xsl:call-template name="display-column-attr-content"/>
        </font></td>
      </xsl:when>
      <xsl:otherwise>
        <td width="150"><b><xsl:value-of select="$item"/>:</b></td>
        <td><xsl:call-template name="display-column-attr-content"/></td>
      </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:if>
</xsl:template>

<xsl:template name="display-column-attr-content">
  <xsl:call-template name="replace-string">
    <xsl:with-param name="text" select="current()"/>
    <xsl:with-param name="replace" select="','"/>
    <xsl:with-param name="with" select="', '"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="replace-string">
  <xsl:param name="text"/>
  <xsl:param name="replace"/>
  <xsl:param name="with"/>
  <xsl:choose>
    <xsl:when test="contains($text,$replace)">
      <xsl:value-of select="substring-before($text,$replace)"/>
      <xsl:value-of select="$with"/>
      <xsl:call-template name="replace-string">
        <xsl:with-param name="text" select="substring-after($text,$replace)"/>
        <xsl:with-param name="replace" select="$replace"/>
        <xsl:with-param name="with" select="$with"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$text"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="break">
  <xsl:param name="text"/>
   <xsl:choose>
   <xsl:when test="contains($text, '&#xa;')">
      <xsl:variable name="lineStr" select="substring-before($text,'&#xa;')"/>
      <xsl:value-of select="$lineStr"/>
      <xsl:if test="$lineStr!=''"><br/></xsl:if>
      <xsl:call-template name="break">
          <xsl:with-param name="text" select="substring-after($text,'&#xa;')"/>
      </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
        <xsl:value-of select="$text"/>
   </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<xsl:template name="tables-display">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="tables1" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/TABLES"/>
  <xsl:variable name="tables2" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/TABLES"/>
  <xsl:if test="$tables1!=''">
    <xsl:for-each select="$tables1/TABLE"> 
      <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="current()"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:if>
  <xsl:if test="not($tables1!='') and $tables2!=''">
    <xsl:for-each select="$tables2/TABLE"> 
      <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="current()"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:if>
</xsl:template>

<xsl:template name="table-display">
  <xsl:variable name="mdoc" select="document($mDescFile)"/>
  <xsl:variable name="odoc" select="document($oDescFile)"/>
  <xsl:variable name="table1" select=
      "$mdoc/CLI/NOUN[@name=current()/@name]/TABLE"/>
  <xsl:variable name="table2" select=
      "$odoc/CLI/NOUN[@name=current()/@name]/TABLE"/>
  <xsl:if test="$table1!=''">
    <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="$table1"/>
    </xsl:call-template>
  </xsl:if>
  <xsl:if test="not($table1!='') and $table2!=''">
    <xsl:call-template name="table-display-content">
        <xsl:with-param name="table" select="$table2"/>
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template name="table-display-content">
  <xsl:param name="table"/>
  <xsl:if test="$table!=''">
    <dl><dl>
      <li><b><xsl:value-of select="$table/TITLE"/></b></li>
      <xsl:variable name="desc" select="$table/DESCRIPTION"/>
      <xsl:if test="$desc!=''">
        <dd>
          <xsl:call-template name="break">
            <xsl:with-param name="text" select="$desc"/>
          </xsl:call-template>
        </dd><br/>
      </xsl:if>
      <table border="1" width="90%" style="font-size:8pt">
        <thead bgColor='lightyellow'>
          <xsl:for-each select="$table/ROW/COLUMN_HEADER">
            <th><b><xsl:value-of select="current()"/></b></th>
          </xsl:for-each>
        </thead>
        <xsl:apply-templates select="$table/ROW"/>
      </table>
    </dl></dl>
  </xsl:if>
</xsl:template>

<xsl:template match="ROW">
  <tr>
  <xsl:for-each select="COLUMN_VALUE">
    <td><xsl:value-of select="current()"/></td>
   </xsl:for-each>
  </tr>
</xsl:template>

</xsl:stylesheet>

